{% extends "photologue/root.html" %}
{% load url from future %}

{% block title %}Galleries for {{ day|date }}{% endblock %}

{% block content %}

<h1>Galleries for {{ day|date }}</h1>

{% if object_list %}
    {% for gallery in object_list %}
    <div class="photo-gallery">
        <h2>{{ gallery.title }}</h2>
        {% for photo in gallery.sample %}
        <div class="gallery-photo">
            <a href="{{ photo.get_absolute_url }}"><img src="{{ photo.get_thumbnail_url }}" alt="{{ photo.title }}"/></a>
        </div>
        {% endfor %}
    </div>
    {% endfor %}
{% else %}
    <p>No galleries were found.</p>
{% endif %}

<p><a href="{% url 'pl-gallery-list' 1 %}">View all galleries.</a></p>

{% endblock %}
