{% extends "photologue/root.html" %}
{% load url from future %}

{% block title %}Galleries for {{ year }}{% endblock %}

{% block content %}

<h1>Galleries for {{ year }}</h1>
<ul>
{% for date in date_list %}
<li><a href="{{ date|date:"M"|lower }}/">{{ date|date:"F" }}</a></li>
{% endfor %}
</ul>

<p><a href="{% url 'pl-gallery-list' 1 %}">View all galleries.</a></p>

{% endblock %}
